@@ -50,7 +50,7 @@ def plant(VERBOSE=0):
     set_verbose_level(VERBOSE)
     # Create beanstalk_stack home
     beanstalk_local_base_path = os.path.normpath(os.path.join(os.getcwd(), BEANSTALK_LOCAL_BASE_PATH))
-    app_settings_path = os.path.normpath(os.path.join(beanstalk_local_base_path, 'beanstalk_app_settings.py'))
+    app_settings_path = os.path.normpath(os.path.join(beanstalk_local_base_path, 'app_settings.py'))
 
     if not os.path.exists(beanstalk_local_base_path):
         print cyan('Make beanstalk_stack local base: ./{path}'.format(path=os.path.relpath(beanstalk_local_base_path)))
@@ -80,7 +80,6 @@ def plant(VERBOSE=0):
     setting_set1 = [
         ('PROJECT_SOURCE_ROOT', 'Project Source Root?', None, 'str'),
         ('PROJECT_NAME', 'Project Name?', None, 'str'),
-        ('PROJECT_VENV_PATH', 'Where\'s your virtualenv?', validate_file_existence, 'obj'),
         ('GIT_IGNORE_PATH', 'Where\'s git ignore file?', validate_file_existence, 'str'),
         None,
         ('WEB_SERVERS', 'Where to deploy? (Python list/tuple with server address)', validate_web_server, 'obj'),
@@ -155,7 +154,7 @@ def deploy(settings_path=None, **settings_patches):
     # Setup environment, ssh, and web servers
     set_verbose_level()
     env.use_ssh_config = beanstalk_settings['USE_SSH_CONFIG']
-    env['shell_env'] = beanstalk_settings['REMOTE_ENVIRONMENTS']
+    env.shell_env = beanstalk_settings['REMOTE_ENVIRONMENTS']
     load_web_servers()
 
     # Start
