@@ -41,10 +41,11 @@ def add(settings_path=None, **settings_patches):
             with open(local_authorized_keys_path, 'r') as local_authorized_keys:
                 for authorized_key in local_authorized_keys:
                     if authorized_key.strip() == ssh_pub_key:
-                        print cyan('You have been in %s.' % host_name)
+                        print cyan('You have been in {host}.'.format(host=host_name))
                         return
             append(ssh_authorized_keys_path, ssh_pub_key)
-            print green('You have joined %s.' % host_name)
+            print green('You have joined {host}.'.format(host=host_name))
 
     with settings(hide('running')):
+        # TODO: Should not prompt beanstalk's SSH password
         execute(add_user_core)
