@@ -7,7 +7,7 @@ from beanstalk import (BEANSTALK_ROOT_PATH, BEANSTALK_GLOBAL_BASE_PATH,
 from beanstalk.titles import section_title
 
 
-def load_role_settings(role=None, local_settings_path=None, load_again=False, default_only=False, **setting_patches):
+def load_role_settings(role=None, load_again=False, default_only=False, **setting_patches):
     """Load beanstalk settings in
     """
     env_key = 'beanstalk_settings' if not default_only else 'beanstalk_default_settings'
@@ -22,22 +22,25 @@ def load_role_settings(role=None, local_settings_path=None, load_again=False, de
 
     # Get default settings path
     setting_paths = []
-    default_settings_path = os.path.join(BEANSTALK_ROOT_PATH, 'default_settings/default_{0}_settings.py'.format(role))
+    default_settings_path = os.path.join(BEANSTALK_ROOT_PATH, 'default_settings/{0}_settings.py'.format(role))
     setting_paths.append(default_settings_path)
     # Get global role settings path
-    global_settings_path = os.path.join(BEANSTALK_GLOBAL_BASE_PATH, '{0}_settings.py'.format(role))
-    if os.path.exists(global_settings_path):
-        setting_paths.append(global_settings_path)
-    # Get local role settings path
     if not default_only:
-        if local_settings_path is None:
-            local_settings_path = env.get(
-                'beanstalk_{0}_settings_path'.format(role),
-                os.path.join(
-                    os.getcwd(), BEANSTALK_LOCAL_BASE_PATH, 'beanstalk_{0}_settings.py'.format(role)
-                ))
-        if os.path.exists(local_settings_path):
-            setting_paths.append(local_settings_path)
+        global_settings_path = os.path.join(BEANSTALK_GLOBAL_BASE_PATH, '{0}_settings.py'.format(role))
+        if os.path.exists(global_settings_path):
+            setting_paths.append(global_settings_path)
+    # Get user role settings path
+    if not default_only:
+        user_settings_path = os.path.expanduser(
+            os.path.join('~/.beanstalk_stack/{0}_settings.py'.format(role)))
+        if os.path.exists(user_settings_path):
+            setting_paths.append(user_settings_path)
+    # Get project role settings path
+    if not default_only:
+        project_settings_path = os.path.join(
+            os.getcwd(), BEANSTALK_LOCAL_BASE_PATH, '{0}_settings.py'.format(role))
+        if os.path.exists(project_settings_path):
+            setting_paths.append(project_settings_path)
 
     beanstalk_settings = SettingsDict(*setting_paths, **setting_patches)
 
